aboutsummaryrefslogtreecommitdiffstats
path: root/LUFA/Drivers/USB/Core/StdDescriptors.h
diff options
context:
space:
mode:
authorDean Camera <dean@fourwalledcubicle.com>2013-11-21 19:19:45 +0100
committerDean Camera <dean@fourwalledcubicle.com>2013-11-21 19:19:45 +0100
commite3cb0f48ef4dbb5211c7db1a7447dc997520d212 (patch)
tree81ec42459d2e133f16769adb3df6f6463151dba7 /LUFA/Drivers/USB/Core/StdDescriptors.h
parent52c69331ec117affc50838d62cb6770cd1d57b95 (diff)
downloadlufa-e3cb0f48ef4dbb5211c7db1a7447dc997520d212.tar.gz
lufa-e3cb0f48ef4dbb5211c7db1a7447dc997520d212.tar.bz2
lufa-e3cb0f48ef4dbb5211c7db1a7447dc997520d212.zip
Use new VERSION_BCD() macro with explicit int arguments to fix edge cases with the previous floating point macro version.
Diffstat (limited to 'LUFA/Drivers/USB/Core/StdDescriptors.h')
-rw-r--r--LUFA/Drivers/USB/Core/StdDescriptors.h23
1 files changed, 9 insertions, 14 deletions
diff --git a/LUFA/Drivers/USB/Core/StdDescriptors.h b/LUFA/Drivers/USB/Core/StdDescriptors.h
index d7f0ca349..d77acf4e3 100644
--- a/LUFA/Drivers/USB/Core/StdDescriptors.h
+++ b/LUFA/Drivers/USB/Core/StdDescriptors.h
@@ -85,17 +85,20 @@
*/
#define USB_STRING_LEN(UnicodeChars) (sizeof(USB_Descriptor_Header_t) + ((UnicodeChars) << 1))
/** Macro to encode a given four digit floating point version number (e.g. 01.23) into Binary Coded
* Decimal format for descriptor fields requiring BCD encoding, such as the USB version number in the
* standard device descriptor.
*
* \note This value is automatically converted into Little Endian, suitable for direct use inside device
* descriptors on all architectures without endianness conversion macros.
*
- * \param[in] x Version number to encode as a 16-bit little-endian number, as a floating point number.
+ * \param[in] Major Major version number to encode.
+ * \param[in] Minor Minor version number to encode.
+ * \param[in] Revision Revision version number to encode.
*/
- #define VERSION_BCD(x) CPU_TO_LE16((VERSION_TENS(x) << 12) | (VERSION_ONES(x) << 8) | \
- (VERSION_TENTHS(x) << 4) | (VERSION_HUNDREDTHS(x) << 0) )
+ #define VERSION_BCD(Major, Minor, Revision) \
+ CPU_TO_LE16( ((Major & 0xFF) << 8) | \
+ ((Minor & 0x0F) << 4) | \
+ (Revision & 0x0F) )
/** String language ID for the English language. Should be used in \ref USB_Descriptor_String_t descriptors
* to indicate that the English language is supported by the device in its string descriptors.
@@ -736,14 +739,6 @@
*/
} ATTR_PACKED USB_StdDescriptor_String_t;
- /* Private Interface - For use in library only: */
- #if !defined(__DOXYGEN__)
- /* Macros: */
- #define VERSION_TENS(x) (int)((int)(x) / 10)
- #define VERSION_ONES(x) (int)((int)(x) % 10)
- #define VERSION_TENTHS(x) (int)((x - (int)x) * 10)
- #define VERSION_HUNDREDTHS(x) (int)((x * 100) - ((int)(x * 10) * 10))
- #endif
/* Disable C linkage for C++ Compilers: */
#if defined(__cplusplus)
@@ -85,17 +85,20 @@
*/
#define USB_STRING_LEN(UnicodeChars) (sizeof(USB_Descriptor_Header_t) + ((UnicodeChars) << 1))
- /** Macro to encode a given four digit floating point version number (e.g. 01.23) into Binary Coded
- * Decimal format for descriptor fields requiring BCD encoding, such as the USB version number in the
- * standard device descriptor.
+ /** Macro to encode a given major/minor/revision version number into Binary Coded Decimal format for descriptor
+ * fields requiring BCD encoding, such as the USB version number in the standard device descriptor.
*
* \note This value is automatically converted into Little Endian, suitable for direct use inside device